Kira v0.1.0 Kira.Progress

Originally progress was tracked in RuntimeState as a integer that started out as the number of branches, and would indecate completion once equal to 0. But that really didn’t accomodate for rollbacks, so this data type was created to track progression with a richer data type.

Link to this section Summary

Link to this section Types

Link to this type t()
t() :: %Kira.Progress{
  applied: integer(),
  applies_retrying: MapSet.t(atom()),
  applies_running: MapSet.t(atom()),
  total: integer(),
  unapplied: integer(),
  unapplies_retrying: MapSet.t(atom()),
  unapplies_running: MapSet.t(atom())
}

Link to this section Functions

Link to this function apply_done?(progress)
apply_done?(progress :: t()) :: boolean()
Link to this function create(total)
create(total :: integer()) :: t()
Link to this function record_apply_done(progress, name)
record_apply_done(progress :: t(), name :: atom()) :: t()
Link to this function record_apply_failure(progress, name)
record_apply_failure(progress :: t(), name :: atom()) :: t()
Link to this function record_apply_start(progress, name)
record_apply_start(progress :: t(), name :: atom()) :: t()
Link to this function record_unapply_done(progress, name)
record_unapply_done(progress :: t(), name :: atom()) :: t()
Link to this function record_unapply_start(progress, name)
record_unapply_start(progress :: t(), name :: atom()) :: t()
Link to this function unapply_done?(progress)
unapply_done?(progress :: t()) :: boolean()