Kira v0.1.0 Kira.Runtime.Apply
Link to this section Summary
Functions
Here we’ll determine if the process should be reattempted or we need to start a rollback
Link to this section Functions
Link to this function
apply_dispatch(source, branch, config, dependencies)
apply_dispatch( source :: pid(), branch :: Kira.Branch.t(), config :: any(), dependencies :: map() ) :: any()
Link to this function
on_apply_error_dispatch(source, branch, config, dependencies, errors)
on_apply_error_dispatch( source :: pid(), branch :: Kira.Branch.t(), config :: any(), dependencies :: map(), errors :: Kira.BranchState.errors() ) :: any()
Link to this function
reattmpt_failed(state, branch, error)
reattmpt_failed( state :: Kira.RuntimeState.t(), branch :: Kira.Branch.t(), error :: any() ) :: Kira.Util.result(any())
Here we’ll determine if the process should be reattempted or we need to start a rollback.
Link to this function
start(state, branch_name)
start(state :: Kira.RuntimeState.t(), branch_name :: atom()) :: Kira.Util.result(Kira.RuntimeState.t())