Kira v0.1.0 Kira.Progress
Originally progress was tracked in RuntimeState as a integer that started out as the number of branches, and would indecate completion once equal to 0. But that really didn’t accomodate for rollbacks, so this data type was created to track progression with a richer data type.
Link to this section Summary
Link to this section Types
Link to this section Functions
Link to this function
record_apply_done(progress, name)
Link to this function
record_apply_failure(progress, name)
Link to this function
record_apply_start(progress, name)
Link to this function
record_unapply_done(progress, name)
Link to this function
record_unapply_start(progress, name)